# Generated by Django 2.2.20 on 2021-05-04 15:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0017_auto_20210125_1847'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='project',
            name='businessProvider',
        ),
        migrations.AddField(
            model_name='businessprovider',
            name='project',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='businessprovider', to='djangoldp_project.Project'),
        ),
    ]



from django.contrib import admin
from djangoldp.admin import DjangoLDPAdmin
from djangoldp.models import Model
from .models import Project, Member, Customer, BusinessProvider


class EmptyAdmin(admin.ModelAdmin):
    def get_model_perms(self, request):
        return {}


class TeamInline(admin.TabularInline):
    model = Member
    exclude = ('urlid', 'is_backlink', 'allow_create_backlink')
    extra = 0


class ProjectAdmin(DjangoLDPAdmin):
    list_display = ('urlid', 'customer', 'name', 'captain', 'status', 'jabberID')
    exclude = ('urlid', 'is_backlink', 'allow_create_backlink', 'jabberID', 'jabberRoom')
    search_fields = ['urlid', 'name', 'members__user__urlid', 'number', 'description',\
        'status', 'captain__urlid', 'customer__urlid', 'customer__name',\
        'businessProvider__urlid', 'businessProvider__name']
    ordering = ['urlid']
    inlines = [TeamInline]

    def get_queryset(self, request):
        # Hide distant projects
        queryset = super(ProjectAdmin, self).get_queryset(request)
        internal_ids = [x.pk for x in queryset if not Model.is_external(x)]
        return queryset.filter(pk__in=internal_ids)


admin.site.register(Project, ProjectAdmin)
admin.site.register(Member, EmptyAdmin)
admin.site.register(Customer, EmptyAdmin)
admin.site.register(BusinessProvider, EmptyAdmin)



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2020-01-14 16:15
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('djangoldp_project', '0006_auto_20200114_1547'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='owner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='owned_customers', to=settings.AUTH_USER_MODEL),
        ),
    ]
